@@ -58,9 +58,8 @@ def escapeMarkdown(text):
 			r.append("\\")
 		r.append(x)
 	text = ''.join(r)
-	for special_char in ['`', 'https://', 'http://']:
+	for special_char in ['`', '*', 'https://', 'http://']:
 		text = text.replace(special_char, '')
-	text = text.replace('*', '\\*') # may need to revisit
 	text = text.replace('t.cn/', ' t.cn/')
 	return compactText(text)
 
@@ -141,6 +140,11 @@ def log_on_fail(debug_group = None, error_to_ignore=[]):
 				tb.print_exc()
 				if debug_group:
 					debug_group.send_message(text=str(e)) 
+					# untested code
+					try:
+						debug_group.send_text(''.join(tb.format_tb()))
+					except Exception as e:
+						debug_group.send_message(text=str(e)) 
 		return applicator
 	return decorate
 
